| DACF-package | R Documentation |
The DACF package is used to conduct data analyses for data with
ceiling/floor effects. The current version contains functions to
estimate mean and variances and to conduct mean comparison tests.
To access this package's tutorial, type the following line into the console:
vignette("DACF-vignette")
Maintainer: Qimin Liu Qliuacademia@gmail.com
Authors:
Lijuan Wang lwang4@nd.edu
Lauren Trichtinger lauren.trichtinger@gmail.com
Other contributors:
Grace Murray gemurray7@gmail.com [contributor]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.