powered by
conduct an F star with for data with ceiling/floor effects
lw.f.star(data, formula, method_type)
a dataframe of data with ceiling/floor effects and corresponding group variables in wide format
a formula denoting the dependent and independent variable, e.g., y~group
a character string specifying the preferred method type. "a" uses the original sample size and "b" uses after-truncation sample size.
the value of the Brown-Forsythe F star statistics
the p-value for the test
effect size estimate in Cohen's f squared
# NOT RUN { dat=threeganova.sim(1000,.16,1) dat[dat$group==1,3]=induce.cfe(0,.15,dat[dat$group==1,3]) lw.f.star(dat,y~group,"a") #using truncated n lw.f.star(dat,y~group,"b") #using original n # }
Run the code above in your browser using DataLab