| rec.mean.var | R Documentation |
recover mean and variance of the data with ceiling/floor effects
rec.mean.var(y, flr, ceil)
y |
a (non-empty) numeric vector of data with ceiling/floor effects |
flr |
a (non-empty) numeric value of the floor threshold (e.g., the minimum score of the measurement scale) |
ceil |
a (non-empty) numeric value of the ceiling threshold (e.g., the maximum score of the measurement scale) |
ceiling.percentage |
the percentage of ceiling values in the data |
floor.percentage |
the percentage of floor values in the data |
est.mean |
estimated mean of the true scores |
est.var |
estimated variance of the true scores |
# simulate normally distributed true scores
x=rnorm(1000,2,4)
mean(x); var(x)
# induce 20% floor effects
# and estimate the true mean variance from the floor data
x.f=induce.cfe(.2,0,x)
rec.mean.var(x.f, flr=min(x.f), ceil=max(x.f))
# induce 20% ceiling effects
# and estimate the true mean and variance from the ceiling data
x.c=induce.cfe(0,.2,x)
rec.mean.var(x.c, flr=min(x.c), ceil=max(x.c))
# induce 20% and 10% of floor and ceiling effects, respectively
# and estimate the true mean and variance from the data with floor and ceiling effects
x.cf=induce.cfe(.2,.1,x)
rec.mean.var(x.cf, flr=min(x.cf), ceil=max(x.cf))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.