| lw.t.test | R Documentation |
conduct a t test adjusting for ceiling and/or floor effects
lw.t.test(x1, x2, flr1, ceil1, flr2, ceil2, method_type)
x1 |
a (non-empty) numeric vector of data values for group 1 with floor/ceiling effects |
x2 |
a (non-empty) numeric vector of data values for group 2 with floor/ceiling effects |
flr1 |
a (non-empty) numeric value of the floor threshold for group 1 |
ceil1 |
a (non-empty) numeric value of the ceiling threshold for group 1 |
flr2 |
a (non-empty) numeric value of the floor threshold for group 2 |
ceil2 |
a (non-empty) numeric value of the ceiling threshold for group 2 |
method_type |
a character string specifying the preferred method type. "a" uses the original sample size and "b" uses after-truncation sample size. |
statistic |
the value of the adjusted t test statistics |
p.value |
the p-value for the test |
est.d |
effect size estimate as in Cohen's d |
conf.int |
95% confidence interval |
x1.c=induce.cfe(0,.3,rnorm(1000,20,5)) #group 1 scores with 30% ceiling data
x2.c=induce.cfe(.15,0,rnorm(1000,30,5)) #group 2 scores with 15% floor data
lw.t.test(x1.c, x2.c, flr1=min(x1.c), ceil1=max(x1.c), flr2=min(x2.c), ceil2=max(x2.c), "a")
lw.t.test(x1.c, x2.c, flr1=min(x1.c), ceil1=max(x1.c), flr2=min(x2.c), ceil2=max(x2.c), "b")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.